<!DOCTYPE TS><TS>
<context>
    <name>CFileIO</name>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFileWriter</name>
    <message>
        <source>error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There was an error writing to the selected file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormDef</name>
    <message>
        <source>Sailcut</source>
        <translation type="obsolete">Sailcut</translation>
    </message>
    <message>
        <source>Sail corners coordinates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>tack</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>clew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>head</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>peak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IRC width measurements</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormDefBase</name>
    <message>
        <source>Sail definition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cloth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leech hem</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other hems</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seam width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>deg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sail area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gaff angle from luff</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Diagonal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mitre cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cross cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Twist foot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of sections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of radial gores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Radial cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rig geometry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fore triangle base  J</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tack height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Distance tack to stem</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main sail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jib</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fore triangle hoist  I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boat length LOA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mast / Luff rake</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sail shape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top depth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mid depth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Foot depth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sail ID </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of luff gores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dihedral angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sail identifier</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>m2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormHelp</name>
    <message>
        <source>Sailcut CAD Handbook</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormMain</name>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>to &amp;DXF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>to &amp;TXT sail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>to &amp;XML sail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xport 3D sail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>to &amp;Carlson plotter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Mould</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Patches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Rig</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sailcut &amp;Handbook</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;Sailcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>shaded view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>wireframe view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>development</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>loaded &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>created new sail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Sailcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>error loading &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>wrote &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There was a data printing error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There was a development printing error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There was a drawing printing error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sailcut data sheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jib</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> sections,   </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rig </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Depth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> head gores,   </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> luff gores.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>deg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export &amp;development</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>to &amp;Hand-plotting format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormMould</name>
    <message>
        <source>Top profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Middle profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical repartition</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormRig</name>
    <message>
        <source>Rig</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sail &amp;definition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3D &amp;sail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add sail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CRigSailWidget</name>
    <message>
        <source>Sail information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CSailViewerPanel</name>
    <message>
        <source>Display parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>elevation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>azimuth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Labeling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>deg</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CWidgetProfile</name>
    <message>
        <source>Luff shape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Depth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leech shape</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XmlReaderTempl</name>
    <message>
        <source>error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
